#!/bin/sh
# \
exec wish "$0" ${1+"$@"}
#
# usage: filesource.tcl [mif-file]

if {[llength $argv] > 1} {
    error {usage: filesource.tcl [mif-file]}
}

set home [string trimright [file dirname [info script]] ./]
set home [file join [pwd] $home]
lappend auto_path [file join [file dirname [file dirname $home]] ext]

#**************************************************************************#  
# Library support
package require Oc
package require Ow
package require Net

Oc_Main SetAppName FileSource
Oc_Main SetVersion 1.0.1.3
regexp \\\044Date:(.*)\\\044 {$Date: 2000/02/23 21:33:15 $} _ date
Oc_Main SetDate [string trim $date]
# regexp \\\044Author:(.*)\\\044 {$Author: dgp $} _ author
# Oc_Main SetAuthor [Oc_Person Lookup [string trim $author]]
Oc_Main SetAuthor [Oc_Person Lookup donahue]
Oc_Main SetHelpURL [Oc_Url FromFilename [file join [file dirname \
        [file dirname [file dirname [Oc_DirectPathname [info \
        script]]]]] doc userguide Micromagnetic_Problem_File_.html]]

#**************************************************************************#  
#top level window
set exportLabel [label .l -relief ridge -bd 4 -padx 4 -pady 4]
pack .l -side top -expand 1

proc SetFilename { newpath newname } {
    global importedFilename exportLabel
    if {[string match {} $newname]} {
	set importedFilename {}
	$exportLabel configure -text "No file selected"
    } else {
	set importedFilename [file join $newpath $newname]
	$exportLabel configure -text "Export: $importedFilename"
    }
}

set newname [lindex $argv 0]
set newpath [file dirname [Oc_DirectPathname $newname]]
set newname [file tail $newname]
SetFilename $newpath $newname

proc Die { win } {
    if {![string match . $win]} { return }  ;# Child destroy event
    global protocol
    if {[info exists protocol]} {
	$protocol Delete; after 2000 exit
    } else {
	exit
    }
}
bind . <Destroy> "+Die %W"

wm title . FileSource<[pid]>
wm iconname . [wm title .]

#**************************************************************************#
# Menubar
set menubar .menubar
foreach {menuname helpmenu} [Ow_MakeMenubar . $menubar File Help] {}
$menuname add command -label "Open..." -command\
           [list LoadButton $menuname "Open..."] -underline 0
$menuname add separator
$menuname add command -label Exit -command {Die .} -underline 1
Ow_StdHelpMenu $helpmenu

#**************************************************************************#
# File select
proc LoadButton { btn item } {
    if { [string match disabled [$btn entrycget $item -state]] } {
        return
    }
    global oommf
    Ow_FileDlg New dialog -callback LoadCallback \
	    -dialog_title "[Oc_Main GetAppName]:Open File" \
	    -selection_title "Open MIF File..." \
	    -select_action_id "OPEN" \
	    -filter "*.mif" \
            -delete_callback_arg \
	    [list $btn entryconfigure $item -state normal]
    $btn entryconfigure $item -state disabled
}
proc LoadCallback { widget actionid args } {
    global resetfilepath
    switch -exact -- $actionid {
	DELETE {
	    eval [join $args]
	    return
	}
	OPEN   {
	    foreach { newpath newfile } [$widget GetFileComponents] {}
	    SetFilename $newpath $newfile
	}
	default {
	    return "ERROR (proc LoadCallBack):\
		    Invalid actionid: $actionid"
	}
    }
}

#**************************************************************************#  
# networking
Net_Protocol New protocol -name "OOMMF ProbEd protocol 0.0"
$protocol AddMessage start HasGui {} {
    return [list start [list 0 0]]
}
$protocol AddMessage start GetProbDescFile {} {
    global importedFilename
    set exportedFilename [Oc_TempName]
    file copy $importedFilename $exportedFilename
    return [list start [list 0 $exportedFilename]]
}
Net_Server New server -protocol $protocol -alias FileSource -log Oc_Nop
$server Start 0

Ow_SetIcon .
vwait forever
